import airflow
from airflow import DAG
from airflow.operators.python import PythonOperator
from airflow.providers.apache.spark.operators.spark_submit import SparkSubmitOperator
from airflow.operators.dagrun_operator import TriggerDagRunOperator
from model_dag import train_and_log_model
from datetime import timedelta

default_args = {
    "owner": "airflow",
    "depends_on_past": False,
    "email_on_failure": False,
    "email_on_retry": False,
    "retries": 1,
    "start_date": airflow.utils.dates.days_ago(1),
}

dag = DAG(
    dag_id="churn_pipeline_init",
    default_args=default_args,
    description="DAG for initial model training",
    schedule_interval=None,
    catchup=False,
)

initial_processing_task = SparkSubmitOperator(
    task_id="data_processing",
    application="/opt/airflow/jobs/data_processor.py",
    conn_id="spark_standalone",
    conf={
        "spark.executor.memory": "1g",
        "spark.driver.memory": "512m",
        "spark.executor.cores": "1",
        "spark.sql.shuffle.partitions": "10",
    },
    name="data_processing_job",
    dag=dag,
)

initial_training_task = PythonOperator(
    task_id="model_training",
    python_callable=train_and_log_model,
    dag=dag,
)

# Trigger churn_pipeline_maintenance 1 minute after this DAG finishes
trigger_maintenance_dag = TriggerDagRunOperator(
    task_id="trigger_churn_pipeline_maintenance",
    trigger_dag_id="churn_pipeline_maintenance",
    conf={},
    wait_for_completion=False,
    reset_dag_run=True,
    execution_date="{{ (execution_date + params.timedelta(minutes=1)).isoformat() }}",
    params={'timedelta': timedelta},
    dag=dag,
)

# Task dependencies
initial_processing_task >> initial_training_task >> trigger_maintenance_dag
