import airflow
from airflow import DAG
from airflow.operators.python import PythonOperator
from airflow.providers.apache.spark.operators.spark_submit import SparkSubmitOperator
from drift_retrain_dag import simulate_data_drift, detect_data_drift, retrain_model

default_args = {
    "owner": "airflow",
    "depends_on_past": False,
    "email_on_failure": False,
    "email_on_retry": False,
    "retries": 1,
    "start_date": airflow.utils.dates.days_ago(1),
}

dag = DAG(
    dag_id="churn_pipeline_maintenance",
    default_args=default_args,
    description="DAG for model maintenance",
    schedule_interval="@daily",
    catchup=False,
)

data_processing_task = SparkSubmitOperator(
    task_id="data_processing",
    application="/opt/airflow/jobs/data_processor.py",
    conn_id="spark_standalone",
    conf={
        "spark.executor.memory": "1g",
        "spark.driver.memory": "512m",
        "spark.executor.cores": "1",
        "spark.sql.shuffle.partitions": "10",
    },
    name="data_processing_job",
    dag=dag,
)

simulate_drift_task = PythonOperator(
    task_id='simulate_data_drift',
    python_callable=simulate_data_drift,
    dag=dag,
)

detect_drift_task = PythonOperator(
    task_id='detect_data_drift',
    python_callable=detect_data_drift,
    dag=dag,
)

retrain_task = PythonOperator(
    task_id='retrain_model',
    python_callable=retrain_model,
    dag=dag,
)

# Task dependencies
data_processing_task >> simulate_drift_task >> detect_drift_task >> retrain_task
