import airflow
from airflow import DAG
from airflow.operators.python import PythonOperator
from airflow.providers.apache.spark.operators.spark_submit import SparkSubmitOperator
import os

# Define default arguments
default_args = {
    "owner": "airflow",
    "depends_on_past": False,
    "email_on_failure": False,
    "email_on_retry": False,
    "retries": 1,
    "start_date": airflow.utils.dates.days_ago(1),
}

dag = DAG(
    dag_id="data_processing_dag",
    default_args=default_args,
    description="A DAG for running PySpark data processing jobs",
    schedule_interval=None,
    catchup=False,
)

start = PythonOperator(
    task_id="start",
    python_callable=lambda: print("Starting data processing jobs..."),
    dag=dag,
)

data_processing = SparkSubmitOperator(
    task_id="data_processing",
    application="/opt/airflow/jobs/data_processor.py",
    conn_id="spark_standalone",
    conf={
        "spark.executor.memory": "1g",
        "spark.driver.memory": "512m",
        "spark.executor.cores": "1",
        "spark.sql.shuffle.partitions": "10",
    },
    name="data_processing_job",
    dag=dag,
)

end = PythonOperator(
    task_id="end",
    python_callable=lambda: print("Data processing jobs completed successfully."),
    dag=dag,
)

# Task dependencies
start >> data_processing >> end
